==> servicecatalog-model-6.8.1-sources.jar: io/fabric8/servicecatalog/api/model/BearerTokenAuthConfigFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BearerTokenAuthConfigFluent<A extends BearerTokenAuthConfigFluent<A>> extends BaseFluent<A>{
  public BearerTokenAuthConfigFluent() {
  }
  public BearerTokenAuthConfigFluent(BearerTokenAuthConfig instance) {
    instance = (instance != null ? instance : new BearerTokenAuthConfig());

    if (instance != null) {
      this.withSecretRef(instance.getSecretRef());
      this.withSecretRef(instance.getSecretRef());
    }
  }
  private LocalObjectReferenceBuilder secretRef;
  public LocalObjectReference buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  public A withSecretRef(LocalObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  public boolean hasSecretRef() {
    return this.secretRef != null;
  }
  public A withNewSecretRef(String name) {
    return (A)withSecretRef(new LocalObjectReference(name));
  }
  public SecretRefNested<A> withNewSecretRef() {
    return new SecretRefNested(null);
  }
  public SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item) {
    return new SecretRefNested(item);
  }
  public SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(java.util.Optional.ofNullable(buildSecretRef()).orElse(null));
  }
  public SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(java.util.Optional.ofNullable(buildSecretRef()).orElse(new LocalObjectReferenceBuilder().build()));
  }
  public SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item) {
    return withNewSecretRefLike(java.util.Optional.ofNullable(buildSecretRef()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BearerTokenAuthConfigFluent that = (BearerTokenAuthConfigFluent) o;
    if (!java.util.Objects.equals(secretRef, that.secretRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  public class SecretRefNested<N> extends LocalObjectReferenceFluent<SecretRefNested<N>> implements Nested<N>{
    SecretRefNested(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    LocalObjectReferenceBuilder builder;
    public N and() {
      return (N) BearerTokenAuthConfigFluent.this.withSecretRef(builder.build());
    }
    public N endSecretRef() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/BearerTokenAuthConfigFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class BearerTokenAuthConfigFluent<A extends BearerTokenAuthConfigFluent<A>> extends BaseFluent<A>{
  public BearerTokenAuthConfigFluent() {
  }
  
  public BearerTokenAuthConfigFluent(BearerTokenAuthConfig instance) {
    this.copyInstance(instance);
  }
  private LocalObjectReferenceBuilder secretRef;
  
  protected void copyInstance(BearerTokenAuthConfig instance) {
    instance = (instance != null ? instance : new BearerTokenAuthConfig());
  
    if (instance != null) {
        this.withSecretRef(instance.getSecretRef());
        this.withSecretRef(instance.getSecretRef());
      }
  }
  
  public LocalObjectReference buildSecretRef() {
    return this.secretRef!=null ?this.secretRef.build():null;
  }
  
  public A withSecretRef(LocalObjectReference secretRef) {
    _visitables.get("secretRef").remove(this.secretRef);
    if (secretRef!=null){ this.secretRef= new LocalObjectReferenceBuilder(secretRef); _visitables.get("secretRef").add(this.secretRef);} else { this.secretRef = null; _visitables.get("secretRef").remove(this.secretRef); } return (A) this;
  }
  
  public boolean hasSecretRef() {
    return this.secretRef != null;
  }
  
  public A withNewSecretRef(String name) {
    return (A)withSecretRef(new LocalObjectReference(name));
  }
  
  public SecretRefNested<A> withNewSecretRef() {
    return new SecretRefNested(null);
  }
  
  public SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item) {
    return new SecretRefNested(item);
  }
  
  public SecretRefNested<A> editSecretRef() {
    return withNewSecretRefLike(java.util.Optional.ofNullable(buildSecretRef()).orElse(null));
  }
  
  public SecretRefNested<A> editOrNewSecretRef() {
    return withNewSecretRefLike(java.util.Optional.ofNullable(buildSecretRef()).orElse(new LocalObjectReferenceBuilder().build()));
  }
  
  public SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item) {
    return withNewSecretRefLike(java.util.Optional.ofNullable(buildSecretRef()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BearerTokenAuthConfigFluent that = (BearerTokenAuthConfigFluent) o;
    if (!java.util.Objects.equals(secretRef, that.secretRef)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(secretRef,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretRef != null) { sb.append("secretRef:"); sb.append(secretRef); }
    sb.append("}");
    return sb.toString();
  }
  public class SecretRefNested<N> extends LocalObjectReferenceFluent<SecretRefNested<N>> implements Nested<N>{
    SecretRefNested(LocalObjectReference item) {
      this.builder = new LocalObjectReferenceBuilder(this, item);
    }
    LocalObjectReferenceBuilder builder;
    
    public N and() {
      return (N) BearerTokenAuthConfigFluent.this.withSecretRef(builder.build());
    }
    
    public N endSecretRef() {
      return and();
    }
    
  
  }

}
